@@ -425,12 +425,17 @@ class Base(Controller):
                 "action" : "store"
             }),
             (['-c','--columns'],{
-                "help" : "Whether column names are",
+                "help" : "Whether column names are present",
                 "action" : "store_true"
             }),
             (['--csv'],{
                 'help' : "Whether to generate csv", 
-                "action" : "store_true"}),
+                "action" : "store_true"
+            }),
+            (['-pk','--primary-key'],{
+                "help" : "Primary key column name (-1 crate a new column)",
+                "action" : "store"
+            }),
             (['-d'],{
                 "help" : "Delimiter for the generated data",
                 "action" : "store"
@@ -443,9 +448,10 @@ class Base(Controller):
         template = self.app.pargs.__dict__.get('t') or self.app.pargs.__dict__.get('template')
         columns = self.app.pargs.__dict__.get('c') or self.app.pargs.__dict__.get('columns')
         csv = self.app.pargs.__dict__.get('csv')
-        
+        primary_key = self.app.pargs.__dict__.get('pk') or self.app.pargs.__dict__.get('primary_key')
         delimiter = self.app.pargs.__dict__.get('d') or ','
-        generate_fake_data(n_lines, template, delimiter, columns, csv)
+        
+        generate_fake_data(n_lines, template, delimiter, columns, csv, primary_key)
         
 
     @ex(
